RivePullToRefreshController class

Constructors

RivePullToRefreshController({Future<void> onRefreshI()?, ScrollController? controller, AnimationController? positionController, Side? side})

Properties

getPositionValue double?
no setter
hashCode int
The hash code for this object.
no setterinherited
onRefresh Future<void> Function()?
onRefresh You can proactively call the refresh function where you want, after resizing or just finishing playing a certain animation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close({Duration? durationClose = const Duration(milliseconds: 200), Curve? curve}) Future
call close when you want hide widget refresh, curve is animation close
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited