RivePullToRefresh class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RivePullToRefresh
Constructors
-
RivePullToRefresh({required Future<
void> onRefresh(), required void onInit(RivePullToRefreshController), required Widget riveWidget, @Deprecated('Please use children and dont need set physics') Widget? child, List<Widget> ? children, required double height, dynamic dxOfPointer(double)?, dynamic callBackNumber(double)?, dynamic bump()?, RivePullToRefreshStyle style = RivePullToRefreshStyle.header, ScrollController? controller, double percentActiveBump = 0.3, double dragSizeFactorLimitMax = 1.5, double sizeFactorLimitMin = 1 / 1.5, double kDragContainerExtentPercentage = 0.25, Duration timeResize = const Duration(milliseconds: 200), Function? onMoveToPositionBumpStart, Curve? curveMoveToPositionBumpStart = Curves.linear, double maxSizePaddingChildWhenPullDown = 0, RiveOpenHeaderStyle? openHeaderStyle = RiveOpenHeaderStyle.moveDown, Side side = Side.top, Key? key}) -
const
Properties
- bump → dynamic Function()?
-
bump call when start animation loading
final
- callBackNumber → dynamic Function(double)?
-
callBackNumber dy percentage of pointer on screen. value return range 0-100 when client scrool scrool down or up
final
- child → Widget?
-
final
-
children
→ List<
Widget> ? -
final
- controller → ScrollController?
-
final
- curveMoveToPositionBumpStart → Curve?
-
curveMoveToPositionBumpStartAn parametric animation easing curve when moving to sizeFactorLimitMin
final
- dragSizeFactorLimitMax → double
-
dragSizeFactorLimitMaxHow much the scroll's drag gesture can overshoot the RefreshIndicator's
final
- dxOfPointer → dynamic Function(double)?
-
dxOfPointer dx percentage of pointer on screen. value return range 0-100 when client scrool left or right
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
height of refresh widget
final
- kDragContainerExtentPercentage → double
-
kDragContainerExtentPercentage The over-scroll distance that moves the indicator to its maximum
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxSizePaddingChildWhenPullDown → double
-
maxSizePaddingChildWhenPullDown only avaible if RivePullToRefreshStyle is floating.
final
- onInit → void Function(RivePullToRefreshController)
-
final
- onMoveToPositionBumpStart → Function?
-
onMoveToPositionBumpStart call when start moving to sizeFactorLimitMin
final
-
onRefresh
→ Future<
void> Function() -
final
- openHeaderStyle → RiveOpenHeaderStyle?
-
openHeaderStyle default is moveDown.
RiveOpenHeaderStyle.moveDown. refresh widget will move on top to down
RiveOpenHeaderStyle.behide. refresh widget will open on center header
final
- percentActiveBump → double
-
percentActiveBump 0.0 > percentActiveBump >= 1.0.
when user stop drang and value of
_positionController> percentActiveBump refresh will callfinal - riveWidget → Widget
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → Side
-
_sidesuport top or bottom rive widget show, default is topfinal - sizeFactorLimitMin → double
-
sizeFactorLimitMin value range 0.0 to dragSizeFactorLimitMax
final
- style → RivePullToRefreshStyle
-
style style floating and header
RivePullToRefreshStyle.floating type make refresh widget on top(Stack) or custom padding of child when client pull, RivePullToRefreshStyle.header type pushed the child down
final
- timeResize → Duration
-
timeResize is Duration moving to sizeFactorLimitMin
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< RivePullToRefresh> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited